@@ -1,14 +1,14 @@
 package Text::Table::HTML::DataTables;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-11-08'; # DATE
-our $DIST = 'Text-Table-HTML-DataTables'; # DIST
-our $VERSION = '0.007'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-12-01'; # DATE
+our $DIST = 'Text-Table-HTML-DataTables'; # DIST
+our $VERSION = '0.008'; # VERSION
+
 sub _encode {
     state $load = do { require HTML::Entities };
     HTML::Entities::encode_entities(shift);
@@ -25,6 +25,7 @@ sub table {
 
     my %params = @_;
     my $rows = $params{rows} or die "Must provide rows!";
+    my $default_length = int($params{default_length} // 1000);
 
     my $max_index = _max_array_index($rows);
 
@@ -47,7 +48,11 @@ sub table {
         buttons => ['colvis', 'print'],
     };
     push @table, 'var dt_opts = ', JSON::PP::encode_json($dt_opts), '; ';
-    push @table, '$(document).ready(function() { $("table").DataTable(dt_opts); });';
+    push @table, '$(document).ready(function() { ', (
+        '$("table").DataTable(dt_opts); ',
+        '$("select[name=DataTables_Table_0_length]").val('.$default_length.'); ', # XXX element name should not be hardcoded, and this only works for the first datatable
+        '$("select[name=DataTables_Table_0_length]").trigger("change"); ',        # doesn't get triggered automatically by previous line
+    ), '});';
     push @table, '</script>'."\n\n";
     push @table, "</head>\n\n";
 
@@ -92,7 +97,7 @@ sub table {
 # FROM_MODULE: PERLANCAR::List::Util::PP
 # BEGIN_BLOCK: max
 sub max {
-    return undef unless @_;
+    return undef unless @_; ## no critic: Subroutines::ProhibitExplicitReturnUndef
     my $res = $_[0];
     my $i = 0;
     while (++$i < @_) { $res = $_[$i] if $_[$i] > $res }
@@ -121,7 +126,7 @@ Text::Table::HTML::DataTables - Generate HTML table with jQuery and DataTables p
 
 =head1 VERSION
 
-This document describes version 0.007 of Text::Table::HTML::DataTables (from Perl distribution Text-Table-HTML-DataTables), released on 2020-11-08.
+This document describes version 0.008 of Text::Table::HTML::DataTables (from Perl distribution Text-Table-HTML-DataTables), released on 2021-12-01.
 
 =head1 SYNOPSIS
 
@@ -202,14 +207,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Text-Table
 
 Source repository is at L<https://github.com/perlancar/perl-Text-Table-HTML-DataTables>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-Table-HTML-DataTables>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Text::Table::HTML>
@@ -222,11 +219,36 @@ L<https://datatables.net>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-Table-HTML-DataTables>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
